pub trait TsInputsAlg {
// Required method
fn describe(shapes: &TsShape) -> Vec<TsArgument>;
}Expand description
States the whole argument product a call takes, in declaration order.
Required Methods
Sourcefn describe(shapes: &TsShape) -> Vec<TsArgument>
fn describe(shapes: &TsShape) -> Vec<TsArgument>
Reads each argument, in the order the declaration states them.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".